/*
 * Initial main.c file generated by Glade. Edit as required.
 * Glade will not overwrite this file.
 */

#ifdef HAVE_CONFIG_H
#  include "config.h"
#endif

#include <stdlib.h>
#include <unistd.h>
#include <stdio.h>
#include <signal.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <gtk/gtk.h>
#include <limits.h>
#include <getopt.h>
#include <glib.h>
#include <glib/gstdio.h>

#include "interface.h"
#include "io-menu.h"
#include "support.h"
#include "process.h"
#include "help.h"
#include "callbacks.h"

#define JACKHOME    ".jack-menu"
#define JACKCONF    "jack-menu.conf"
#define JACKRC      "jackrc"

GtkWidget *main_window, *widget;
gchar filepath[255];
GdkColor background;


static sigset_t signals;

static void help()
{
	printf(
		"\n"
		"Usage: jackeq [options]\n"
		"\n"
		"Available options:\n"
		"\n"
		"  -d,--daemon		Daemon Mode\n"
		"  -g,--gui		gtk2 GUI Mode\n"
		"\n"
		"  -h,--help		Print this help message\n"
		"\n");
}



int main(int argc, char *argv[])
{
    char rcfile[PATH_MAX], title[128];
    int fd;
    int run;
    int sig;
    sigset_t allsignals;
    	
    int opt;
    int option_index;
    const char *options = "dgh";

    struct option long_options[] = {
	{ "daemon", 0, 0, 'd' },
	{ "gui", 0, 0, 'g' },
	{ "help", 0, 0, 'h' },
	{ 0, 0, 0, 0 }
    };
    
	sigemptyset (&signals);
	sigaddset(&signals, SIGHUP);
	sigaddset(&signals, SIGINT);
	sigaddset(&signals, SIGQUIT);
	sigaddset(&signals, SIGPIPE);
	sigaddset(&signals, SIGTERM);
	sigfillset (&allsignals);
		      
#ifdef ENABLE_NLS
    bindtextdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
    textdomain(GETTEXT_PACKAGE);
#endif

    printf(PACKAGE " " VERSION "\n");
    printf("(c) 2012 P. Shirkey\n");
    printf("With assistance from J. O'Quin on the awesome JACK i/o dropdown menu\n");
    printf("This is free software, and you are welcome to redistribute it\n" 
	   "under certain conditions; see the file COPYING for details.\n");

	while ((opt = getopt_long(argc, argv, options, long_options, &option_index)) != EOF) {
	    switch(opt) {
		case 'd':

		    printf("Running in Daemon Mode\n"); 
		    
		    /***********************************************
		     *  Move Below code into a seperate file for handling daemon controls/OSC 
		     ***********************************************/
		    
		    int g, i;
		    
		    for (g=0; g < 4; g++) {
			for (i=0; i < 6; i++) {		    
			    global_group[g][i] = i;
			}
		    }	
		    
		    /************************************************
		     *  Move Above code into a seperate file for handling daemon controls/OSC 
		     ************************************************/
		    
		    process_init();
		    run = TRUE;

		    while (run){
			
//		    printf("Daemon loop 1\n");
		    
		    
/*		    Use Sigwait because JACK does 
 *		    and it also catches ^C from keyboard 
 */

		    sigwait(&signals, &sig);
			
		    }   	
			
		    	   	
		      
		return 0;
				
		case 'h':
		
		  help();
		  return 0;

	    }
	}


    /* look for the rcfile, if its there parse it */

    snprintf(rcfile, PATH_MAX, "%s/%s/%s", getenv("HOME"), JACKHOME, JACKRC);
    if ((fd = open(rcfile, O_RDONLY)) >= 0) {	
	close(fd);
	printf("Using jack-menu rc file: %s\n", rcfile);
	gtk_rc_parse(rcfile);
    }


    gtk_set_locale();
    gtk_init(&argc, &argv);
    add_pixmap_directory(PACKAGE_DATA_DIR "/jack-menu");
    main_window = create_window1();
    
    snprintf(title, sizeof(title), PACKAGE " " VERSION);
    gtk_window_set_title ((GtkWindow *) main_window, title);

    gtk_widget_show(main_window);
    bind_iomenu();

    g_snprintf(filepath, 255, "%s/%s/%s", getenv("HOME"), JACKHOME, JACKCONF);
    g_print(_("loading default config file %s\n"), filepath); 
    //getSettings();
    
/* Set background color for interface */    
    background.red = 45055;
    background.green = 47000;
    background.blue = 50355;
    
    gtk_widget_modify_bg (main_window, GTK_STATE_NORMAL,  &background);
     
    /* start I/O processing, then run GTK main loop, until "quit" */

    process_init();
    gtk_main();
    
    return 0;	
	
		
	
}

